CodeTabsBypassProxy class
api.codetabs.com proxy
- Inheritance
-
- Object
- BypassProxy
- CodeTabsBypassProxy
Constructors
- CodeTabsBypassProxy()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildProxyUrl(
String pageUrl) → String -
Builds the proxied url
override
-
extractPageSource(
String responseBody) → String -
Returns the page source from the response body
override
-
fetchPageSource(
{required String method, required String url, Map< String, String> ? headers, Object? body}) → Future<String> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited